===========
ABBR Client
===========


.. image:: https://img.shields.io/pypi/v/acdh_abbr_client.svg
        :target: https://pypi.python.org/pypi/acdh_abbr_client

.. image:: https://img.shields.io/travis/acdh-oeaw/acdh_abbr_client.svg
        :target: https://travis-ci.com/acdh-oeaw/acdh_abbr_client

.. image:: https://readthedocs.org/projects/acdh-abbr-client/badge/?version=latest
        :target: https://acdh-abbr-client.readthedocs.io/en/latest/?badge=latest
        :alt: Documentation Status


.. image:: https://pyup.io/repos/github/acdh-oeaw/acdh_abbr_client/shield.svg
     :target: https://pyup.io/repos/github/acdh-oeaw/acdh_abbr_client/
     :alt: Updates



A python client to interact with abbr.acdh.oeaw.ac.at


* Free software: MIT license
* Documentation: https://acdh-abbr-client.readthedocs.io.


Features
--------

* TODO

Credits
-------

This package was created with Cookiecutter_ and the `audreyr/cookiecutter-pypackage`_ project template.

.. _Cookiecutter: https://github.com/audreyr/cookiecutter
.. _`audreyr/cookiecutter-pypackage`: https://github.com/audreyr/cookiecutter-pypackage
